#!/bin/sh
#
# File:         config_tec.sh
#
# Product:      Tivoli Module
# Description:  Shell Script
# Author:               Module Generator
#
# Generated:    
#
# (C) COPYRIGHT Tivoli Systems, Inc., 1997
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#
if [ -n "" ]; then
        set -x
fi

TASK_PROGPATH=`echo $0 | sed -e 's.\\\\./.g'`
THIS_SCRIPT="config_tec.sh"

#
#	The standard directory and the /Plus override script
#
ETC=/etc/Tivoli
SCRIPT=PLUSsetup_env.sh

#
#	If this is NT, then etc is in a different location
#
if [ x\"$OS\" = x\"Windows_NT\" ] ; then
     ETC=$SystemRoot/system32/drivers/etc/Tivoli
fi

#
#	Look for our override script, if not there, then use the
#		standard one.
#
if [ ! -f $ETC/$SCRIPT ]; then
	SCRIPT=setup_env.sh
fi

. $ETC/$SCRIPT


#
#	Set up some popular environment variables.
#
OSERV=`objcall 0.0.0 get_oserv`
export OSERV
INST_DIR=`objcall $OSERV query install_dir`
INST_DIR=`echo $INST_DIR | tr "\\\\\\\\" "/"`
export INST_DIR
REGION=`objcall $OSERV query whoami | awk '{print $1}'`

LIBRARY=`wlookup Library`

#
#	Get the region name to avoid collisions
#
IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`

DEFSEN=\"TivoliSentryDefaults#$IRONAME\"

MNOID=`objcall 0.0.0 get_host_location`
eval MNNAME=`idlattr -t -g $MNOID label string`
export MNNAME

PLUSDIR=$INST_DIR/generic_unix/TME/PLUS
LINKDIR=$PLUSDIR/LINK
PRODDIR=$PLUSDIR/IBMCSOS2
PATH=$LINKDIR:$PRODDIR:$PATH
export PATH

cd $PRODDIR

. ./PLUSproduct-info.sh
export WINSTRUCTED
export MODULE_VERSION

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts is
#		redirected to a file in TEMP by the same name as the script.
#
TEMP=/tmp
if [ x"$OS" = x"Windows_NT" ]; then
	TEMP=$DBDIR/tmp
else
	TEMP=/tmp
fi

DEBUGDIR=$TEMP/.plusdebug
[ -d "$DEBUGDIR" ] \
  && echo "*** Results redirected to $DEBUGDIR/$THIS_SCRIPT" \
  && exec > $DEBUGDIR/$THIS_SCRIPT 2>&1 && set -xv
[ -f "$DEBUGDIR" ] && set -xv
if [ -d "$DEBUGDIR" -o -f "$DEBUGDIR" -o "$DEBUG" = true ]; then
  DEBUG=true
else
  DEBUG=false
fi
export DEBUG

#
#	Messages
#
ERRNORULEBASE="Error: Missing value for argument \"Rule Base Name\""

SOURCE_NAME=PLUSTASKS

###################
# Support Functions
###################

errexit()
{
	echo "$*" >&2
	exit 1
}

. $LINKDIR/PLUScommon-tec-install.sh

# This machine must be the TEC server.

THIS_HOST_INDEX=`objcall 0.0.0 self | awk -F. '{print $2}'`
TEC_SERVER_INDEX=`wlookup -r EventServer "EventServer#$IRONAME" | awk -F. '{print $2}'`
if [ "$THIS_HOST_INDEX" != "$TEC_SERVER_INDEX" ] ; then
     errmsg  This host is not the TEC server
     exit 1
fi


echo "*** Executing $THIS_SCRIPT ($TASK_PROGPATH)"

###################
# Process Arguments
###################

#
#	Usage Check
#

if [ $# -ne 4 ]; then
     errmsg    Usage: $0 NewRulebase CloneRulebase RulebasePath EventConsole
     exit 1
fi

RB_NAME=$1
RB_TO_CLONE=$2
RB_PATH=$3
EV_CONSOLE=$4

if [ ! "$RB_NAME" ]; then
	errexit "$ERRNORULEBASE"
fi

#UseNew=$1
#UseExisting=$2
#ExistingRulebase=$3
#NewRulebase=$4
#CloneRulebase=$5
#RulebasePath=$6
#EventConsole=$7

#
#  Map arguments to some standard variable names
#
if [ "$RB_TO_CLONE" ]; then
  UseNew=on
  NewRuleBase="$RB_NAME"
  CloneRulebase="$RB_TO_CLONE"
else
  UseExisting=on
  ExistingRuleBase="$RB_NAME"
fi
RulebasePath="$RB_PATH"
EventConsole="$EV_CONSOLE"


if   [ "$UseNew" = on ]; then
	Rulebase="$NewRuleBase"
 	if wlsrb "^${Rulebase}$" > /dev/null 2>&1 ;then
		errmsg "There is an existing '${Rulebase}' rule base."
		exit 1
	fi
elif [ "$UseExisting" = on ]; then
	Rulebase=$ExistingRuleBase
	if wlsrb "^${Rulebase}$" >/dev/null 2>&1 ;then
		debugmsg "Found rule base '${Rulebase}'"
	else
		errmsg "The rule base '${Rulebase}' does not exist." >&2
		exit 1
	fi
else
	errmsg "You must specify either a new or an existing rule base."
	exit 1
fi

Sources="Source1 Source2 Source3"
Source1="$SOURCE_NAME"  Source1Bitmap="JLINK"
Source2="SENTRY"        Source2Bitmap="sentry48"
Source3="OS2"       Source3Bitmap="logf48"

Filters="Filter1 Filter2 Filter3"
Filter1="-c ${SHORT_Prodname}Base -s $SOURCE_NAME"
Filter2="-c ${SHORT_Prodname}Base -s OS2"
Filter3="-c ${SHORT_Prodname}IBM_Monitors_for_CSOS2__V2_0 -s SENTRY"
#Filter1="-c Sentry2_0 -s SENTRY"


PlusRules="$LINKDIR/tivoli_plus.rls"
RulesFiles="$PlusRules"
for f in $TEC_RULE_FILES; do
	eval RULE_FILE='"$'$f'"'
	RulesFiles="$RULE_FILE $RulesFiles"
done
#for f in $TEC_BAROC_FILES; do
#	eval BAROC_FILE='"$'$f'"'
#	ClassFiles="$ClassFiles $BAROC_FILE"
#done

ClassFiles="$PRODDIR/csos2.baroc $PRODDIR/IBM_Monitors_for_CSOS2__V2_0.baroc"
ClassIfPresent="${SHORT_Prodname}Base"

SentryClassFile=Sentry2_0  # does not need full path?
SentryClassFiles="$LINKDIR/Sentry.baroc $LINKDIR/Sentry2.0Monitors.baroc"

EventGroup="${SHORT_Prodname}Plus"

verify_rule_base
if $CreateNewRulebase; then
	echo Creating new rulebase $Rulebase
	verify_clone_rule_base
	VerificationRB=$CloneRulebase
else
	echo $Rulebase already exists
	VerificationRB=$Rulebase
fi
verify_event_console
verify_sentry_classes
verify_current_rule_base_compiles

if $CreateNewRulebase; then
	create_new_rule_base
	clone_rule_base
	verify_new_rule_base_compiles
fi

# delete the existing version of the class files
wdelrbclass csos2.baroc $Rulebase 	>/dev/null 2>&1
wdelrbclass IBM_Monitors_for_CSOS2__V2_0.baroc $Rulebase	>/dev/null 2>&1

import_new_classes

$PreDeletePlusRules && delete_plus_rules
import_new_rules

verify_new_rule_base_compiles


# @E52A8
# the later check in install_new_event_source to see if the sources already exist
# fails on TME 3.6 so we will go ahead and delete the sources here,
# since they will be added back later
for SourceID in $Sources
do
    eval TmpSource=$"$SourceID"
    wdelsrc $TmpSource >/dev/null 2>&1
done


install_new_event_source
install_new_event_group
install_new_event_filters

assign_event_group_to_console

rm -rf $DBDIR/TEC/rb_dir
load_new_rules

install_trouble_ticket_script

restart_event_server
