#!/bin/sh
# COPYRIGHT: Licensed Materials - Property of IBM
#
#            5639-F25 (C) Copyright IBM Corp. 1998
#            All rights reserved.
#
#            U.S. Government Users Restricted Rights -
#            Use, duplication or disclosure restricted by
#            GSA ADP Schedule Contract with IBM Corp.
#
#
# Product:      IBMCSOS2Plus for Tivoli
#
# Description:  Comm Server for OS2 File package configuration script.
#


#
#       The standard directory and the /Plus override script
#
ETC=/etc/Tivoli
SCRIPT=PLUSsetup_env.sh

#
#       If this is NT, then etc is in a different location
#
if [ x\"$OS\" = x\"Windows_NT\" ] ; then
     ETC=$SystemRoot/system32/drivers/etc/Tivoli
fi

#
#       Look for our override script, if not there, then use the
#               standard one.
#
if [ ! -f $ETC/$SCRIPT ]; then
        SCRIPT=setup_env.sh
fi

. $ETC/$SCRIPT

#
#       Set up some popular environment variables.
#
OSERV=`objcall 0.0.0 get_oserv`
export OSERV
INST_DIR=`objcall $OSERV query install_dir`
INST_DIR=`echo $INST_DIR | tr "\\\\\\\\" "/"`
export INST_DIR
REGION=`objcall $OSERV query whoami | awk '{print $1}'`

LIBRARY=`wlookup Library`

#
#       Get the region name to avoid collisions
#
IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`

DEFSEN=\"TivoliSentryDefaults#$IRONAME\"

MNOID=`objcall 0.0.0 get_host_location`
eval MNNAME=`idlattr -t -g $MNOID label string`
export MNNAME
SRC_HOST="$MNNAME"

PLUSDIR=$INST_DIR/generic_unix/TME/PLUS
LINKDIR=$PLUSDIR/LINK
PRODDIR=$PLUSDIR/IBMCSOS2
PATH=$LINKDIR:$PRODDIR:$PATH

cd $PRODDIR

. ./PLUSproduct-info.sh

#
#       Debugging code: by creating a directory called .plusdebug in
#               the appropriate TEMP directory, the output of scripts is
#               redirected to a file in TEMP by the same name as the script.
#
TEMP=/tmp
if [ x"$OS" = x"Windows_NT" ]; then
        TEMP=$DBDIR/tmp
else
        TEMP=/tmp
fi

DEBUGDIR=$TEMP/.plusdebug

SCRIPTNAME=`echo $0 | tr "\\\\\\\\" "/"`
SCRIPTNAME=`basename $SCRIPTNAME`

[ -d "$DEBUGDIR" ] && exec > $DEBUGDIR/$SCRIPTNAME && set -xv
[ -f "$DEBUGDIR" ] && set -xv


##########################
# Variable Initializations
##########################

#. /etc/Tivoli/setup_env.sh
. $ETC/$SCRIPT


OSERV=`objcall 0.0.0 get_oserv`
INST_DIR=`objcall $OSERV query install_dir`
INST_DIR=`echo $INST_DIR | tr "\\\\\\\\" "/"`
export INST_DIR
PLUSBINDIR=$INST_DIR/generic_unix/TME/PLUS/IBMCSOS2
LINKDIR=$INST_DIR/generic_unix/TME/PLUS/LINK
TOOLSDIR=$INST_DIR/w32-ix86/tools
unset types TYPES

PATH=$PLUSBINDIR:$LINKDIR:$PATH:/usr/bin:/usr/ucb:/usr/sbin:/sbin
export PATH

#Get the region name to avoid collisions
IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`


###################
# Support Functions
###################
errexit()
{
        echo "$*" >&2
        exit 1
}


###################
# Process Arguments
###################

#### Script arguments; the following lists are ordered.

ARGS="TGT_DRIVE TGT_LANG"

if [ $# -ne `echo $ARGS | wc -w` ]; then
        errexit Usage: csos2_config_fp `echo $ARGS | tr '[A-Z]' '[a-z]'`
fi

TGT_DRIVE=$1

TGT_LANG=$2

if [ ! "$TGT_LANG" ] ; then
  TGT_LANG = "English"
fi

FPDESC=$TEMP/csos2.fp
FPDESCN=$TEMP/csos2n.fp
FPDIR=$TGT_DRIVE:/cmlib
TGT_DIR=$FPDIR


##################
# Create Nested File Pack that picks up files from the Plus Module host
##################

#Start with the basic Filepackage Keywords
echo "#*TFP-v2.02     Tivoli Filepack (version v2.02)" > $FPDESCN

#Disable descend_dirs
echo descend_dirs=n >> $FPDESCN

#Setup so nested filepacks get distributed first
echo nested_first=y >> $FPDESCN

#Setup for logging
echo log_host=$MNNAME >> $FPDESCN
LF=$TEMP/csos2_install.log
echo log_file=$LF >> $FPDESCN

#Set the Relative path on the source
echo src_relpath=/ >> $FPDESCN

#Set the destination path
echo os2_platform_prefix=$FPDIR >> $FPDESCN

#Concatenate the source with the existing path
echo keep_paths=n >> $FPDESCN

# Add the end marker
echo "%" >> $FPDESCN

#######################################
# List Of Files to be distributed ... #
#######################################

# pull in 

# our exe programs
echo $PLUSBINDIR/cmstmon.exe        >> $FPDESCN
echo $PLUSBINDIR/cmlnkmon.exe       >> $FPDESCN
echo $PLUSBINDIR/cmsesmon.exe       >> $FPDESCN
echo $PLUSBINDIR/cmsendmc.exe       >> $FPDESCN
echo $PLUSBINDIR/cmlicmon.exe       >> $FPDESCN
echo $PLUSBINDIR/cmwaitpl.exe       >> $FPDESCN

if [ "$TGT_LANG" = "German" ] ; then
 cp $PLUSBINDIR/msg.ger $PLUSBINDIR/msgcon.txt 
fi 
if [ "$TGT_LANG" = "Italian" ] ; then
 cp $PLUSBINDIR/msg.ita $PLUSBINDIR/msgcon.txt  
fi
if [ "$TGT_LANG" = "French" ] ; then
 cp $PLUSBINDIR/msg.fre $PLUSBINDIR/msgcon.txt 
fi 
if [ "$TGT_LANG" = "Japanese" ] ; then
 cp $PLUSBINDIR/msg.jpn $PLUSBINDIR/msgcon.txt
fi
if [ "$TGT_LANG" = "Spanish" ] ; then
 cp $PLUSBINDIR/msg.spa $PLUSBINDIR/msgcon.txt  
fi 
if [ "$TGT_LANG" = "BrazilianPortugese" ] ; then
 cp $PLUSBINDIR/msg.ptb $PLUSBINDIR/msgcon.txt  
fi
if [ "$TGT_LANG" = "English" ] ; then
 cp $PLUSBINDIR/msg.eng $PLUSBINDIR/msgcon.txt
fi
if [ "$TGT_LANG" = "Korean" ] ; then
 cp $PLUSBINDIR/msg.kor $PLUSBINDIR/msgcon.txt  
fi
if [ "$TGT_LANG" = "ChineseSimplified" ] ; then
 cp $PLUSBINDIR/msg.prc $PLUSBINDIR/msgcon.txt  
fi
if [ "$TGT_LANG" = "ChineseTraditional" ] ; then
 cp $PLUSBINDIR/msg.roc $PLUSBINDIR/msgcon.txt
fi
 
echo $PLUSBINDIR/msgcon.txt      >> $FPDESCN
 
# our fmt file
echo $PLUSBINDIR/csos2.fmt          >> $FPDESCN
echo $PLUSBINDIR/csos2.cnf          >> $FPDESCN

# add the end marker
echo "%" >> $FPDESCN

#######################################
# List of nested file packages ...    #
#######################################

# add the end marker
echo "%" >> $FPDESCN

#######################################
# List of excluded files ...          #
#######################################

# add the end marker
echo "%" >> $FPDESCN

# File package to configure
FP="Ancillary Filepack for CSOS2"

# Create this file package on the node we are running on, since the above
# files are only accessible on this node
if  wimprtfp -h @ManagedNode:"$MNNAME" @FilePackage:"$FP#$IRONAME" < $FPDESCN
then
        STATUS=$?
        echo
        echo Successfully configured the FilePackage named \"$FP\"
else
        STATUS=$?
        echo Error configuring the FilePackage named \"$FP\" >&2
fi

##################
# Create File Pack
##################

#Start with the basic Filepackage Keywords
echo "#*TFP-v2.02     Tivoli Filepack (version v2.02)" > $FPDESC

#Disable descend_dirs
echo descend_dirs=y >> $FPDESC

#Setup so nested filepacks get distributed first
echo nested_first=y >> $FPDESC

#Setup for logging
echo log_host=$MNNAME >> $FPDESC
LF=$TEMP/csos2_install.log
echo log_file=$LF >> $FPDESC

#Set the Relative path on the source
echo src_relpath=/ >> $FPDESC

#Set the destination path
echo os2_platform_prefix=$FPDIR >> $FPDESC

#Concatenate the source with the existing path
echo keep_paths=n >> $FPDESC

#Set UNIX Platforms to bounce
#Set to skip distribution if before script fails
echo unix_before_skip_non_zero=y >> $FPDESC
echo unix_before_prog_path=tiv_noop >> $FPDESC

#Set PC Platforms to bounce
echo nw_before_skip_non_zero=y >> $FPDESC
echo nw_before_prog_path=tiv_noop >> $FPDESC
echo dos_before_skip_non_zero=y >> $FPDESC
echo dos_before_prog_path=tiv_noop >> $FPDESC
echo win_before_skip_non_zero=y >> $FPDESC
echo win_before_prog_path=tiv_noop >> $FPDESC
echo win95_before_skip_non_zero=y >> $FPDESC
echo win95_before_prog_path=tiv_noop >> $FPDESC

#Set NT Platforms ops
echo nt_after_prog_path=tiv_noop >> $FPDESC
echo nt_after_input_path=tiv_noop >> $FPDESC
echo nt_before_skip_non_zero=y >> $FPDESC
echo nt_after_option= >> $FPDESC

#... Set OS2 Platforms to bounce
echo os2_before_skip_non_zero=y >> $FPDESC

# Add the end marker
echo "%" >> $FPDESC

#######################################
# List Of Files to be distributed ... #
#######################################

# add the end marker
echo "%" >> $FPDESC 

#######################################
# List of nested file packages ...    #
#######################################

# pull in file package from the Plus Module host

echo '"Ancillary Filepack for CSOS2'#$IRONAME'"' >> $FPDESC

# add the end marker
echo "%" >> $FPDESC

#######################################
# List of excluded files ...          #
#######################################

# add the end marker
echo "%" >> $FPDESC

# File package and Profile Manager to configure
FP="Filepack Distribution for CSOS2"
FPM="Filepack Distribution for CSOS2"

if wcrtsprf "NCLINK" "$FPM" FilePackage "$FP" "$FPM"  &&
   wimprtfp -h @ManagedNode:"$SRC_HOST" @FilePackage:"$FP#$IRONAME" < $FPDESC
then
        STATUS=$?
        echo
        echo Successfully configured the FilePackage named \"$FP\"
else
        STATUS=$?
        echo Error configuring the FilePackage named \"$FP\" >&2
fi

#rm -f $FPDESC
exit $STATUS
