#!/bin/sh
# $Id: $
#
# Component:	TivoliPlus Generic Installation Script.
#
# $Source: $
# $Revision: $
#
# Description:  
#		
#
# Author:	Fran Costanzo
#		Tivoli Systems, Inc.
#
# (C) COPYRIGHT Tivoli Systems, Inc. 1996
# Unpublished Work
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#

#
#	Setup Tivoli environment variables and call script
#	to set up product specific stuff.
#
ETC=/etc
if [ x"$OS" = x"Windows_NT" ] ; then
	ETC=$SystemRoot/system32/drivers/etc
fi

#
#	Point at Tivoli stuff
#
. $ETC/Tivoli/setup_env.sh

#
#	get all the common functions loaded
#
. $LINKDIR/PLUScommon-install.sh

check_apps_installed

if $TEC_INSTALLED; then
	TEC_SENTRY_INFORMATIONAL_CLAUSE="-T HARMLESS EventServer#${IRONAME}"
	TEC_SENTRY_RESET_CLAUSE="-T HARMLESS EventServer#${IRONAME}"
	TEC_SENTRY_NORMAL_CLAUSE="-T HARMLESS EventServer#${IRONAME}"
	TEC_SENTRY_FATAL_CLAUSE="-T FATAL EventServer#${IRONAME}"
	TEC_SENTRY_CRITICAL_CLAUSE="-T CRITICAL EventServer#${IRONAME}"
	TEC_SENTRY_SEVERE_CLAUSE="-T MINOR EventServer#${IRONAME}"
	TEC_SENTRY_MINOR_CLAUSE="-T MINOR EventServer#${IRONAME}"
	TEC_SENTRY_WARNING_CLAUSE="-T WARNING EventServer#${IRONAME}"
	TEC_SENTRY_HARMLESS_CLAUSE="-T HARMLESS EventServer#${IRONAME}"
fi

cd $PRODDIR
. ./PLUSproduct-info.sh

if [ "$WINSTRUCTED" = true ]; then
	log_failure "Informational script $PRODDIR/PLUSproduct-info.sh was produced by winstruct and cannot be used for this install process."
	exit 1
fi
WINSTRUCTED=false; export WINSTRUCTED

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts is
#		redirected to a file in TEMP by the same name as the script.
#
TEMP=/tmp
if [ x"$OS" = x"Windows_NT" ]; then
	TEMP=$DBDIR/tmp
else
	TEMP=/tmp
fi

DEBUGDIR=$TEMP/.plusdebug
if [ -d "$DEBUGDIR" -o -f "$DEBUGDIR" -o "$DEBUG" = true ]; then
  DEBUG=true
else
  DEBUG=false
fi
## just make it true always...
DEBUG=true
export DEBUG

#
# Set shell flags for trace, abort install if error
#
if $DEBUG; then set -xv; fi
set -e

#
# Start processing info here
#
common_init || exit 1

log_start_install

#
#	set install options
#
set_install_options || exit 1

#
# Create the collection for this module in the TivoliPlus collection
#
create_plus_collection || exit 1

#
# Create application launch icons
#
create_app_launch || exit 1

#
# Create subscription list profile managers.
#
create_subscription_lists || exit 1

#
# Determine to which subscription list, if any, this host should be added
#
add_host_to_subscription_lists || exit 1

#
# Create task collections and tasks
#
create_task_collections || exit 1

#
# Create application management tasks
#
create_administrative_tasks || exit 1

#
# Create /Plus configuration tasks.
#
create_plus_config_tasks || exit 1

#
# If Sentry is installed, then create the profile managers and indicator
#	collections
#
if $SENTRY_INSTALLED ; then
	#
	# Create hidden tasks to be called from
	#	sentry monitors
	#
	create_sentry_hidden_tasks || exit 1
	#
	# Create the sentry profiles and monitors
	#
	create_sentry_profiles || exit 1
else
	echo Tivoli/Sentry NOT installed!
fi

#
# If Courier is installed, then create the file packages
#
if $COURIER_INSTALLED ; then
	create_file_packages || exit 1
else
	echo Tivoli/Courier NOT installed!
fi

#
# If TEC is installed, then create the events and load rule bases
#
if $TEC_INSTALLED ; then
	#
	# Create hidden tasks
	#
	create_tec_hidden_tasks || exit 1

	#
	# Install TEC and Logfile adapter config tasks
	#
	create_tec_config_tasks || exit 1
	create_log_config_tasks || exit 1
else
	echo Tivoli Enterprise Console NOT installed!
fi

#
# Run the configuration task, if it exists
#
if [ -f $PRODDIR/PLUSconfig.sh ]; then
	chmod +x $PRODDIR/PLUSconfig.sh
	$PRODDIR/PLUSconfig.sh
fi

touch $DBDIR/${SHORT_prodname}plus-installed

log_end_install

#
# Save the log files if $DEBUGDIR exists
#
if [ -d "$DEBUGDIR" ]; then
	cp $TEMP/${SHORT_PRODNAME}* $DEBUGDIR/.
fi

exit 0
